<?php

/**
 * @file
 * Administration pages for cloudwords.module.
 */

/**
 * Main configuration form.
 */
function cloudwords_settings_form($form, &$form_state) {

  $form['cloudwords_client_mode'] = array(
    '#type' => 'radios',
    '#title' => t('Environment'),
    '#description' => t('Configure whether to use the staging or production environment.'),
    '#required' => TRUE,
    '#default_value' => variable_get('cloudwords_client_mode', 'production'),
    '#options' => array('production' => t('Production'), 'stage' => t('Stage')),
  );

  $description = t('The API authorization token generated by Cloudwords.');
  $description .= ' ' . t('Follow the instructions to <a target="_blank" href="https://app.cloudwords.com/cust.htm#settings/myaccount/api">generate an API key</a> for your user.');

  $form['stage_fieldset'] = array(
    '#type' => 'fieldset',
    '#title' => t('Authorization URLs'),
  );

  $form['stage_fieldset']['cloudwords_app_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Cloudwords Application URL'),
    '#required' => FALSE,
    '#size' => 100,
    '#default_value' => variable_get('cloudwords_app_url', 'https://app-sandbox.cloudwords.com'),
  );

  $form['stage_fieldset']['cloudwords_api_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Cloudwords API URL'),
    '#required' => FALSE,
    '#size' => 100,
    '#default_value' => variable_get('cloudwords_api_url', 'https://api-sandbox.cloudwords.com'),
  );


  $form['cloudwords_auth_token'] = array(
    '#type' => 'textfield',
    '#title' => t('API Authorization Token'),
    '#description' => $description,
    '#required' => TRUE,
    '#size' => 70,
    '#default_value' => variable_get('cloudwords_auth_token'),
  );

  $form = system_settings_form($form);

  $form['actions']['refresh'] = array(
    '#type' => 'submit',
    '#value' => t('Refresh translatables'),
    '#submit' => array('cloudwords_refresh_translatables'),
  );

  $form['#attached']['js'][] = drupal_get_path('module', 'cloudwords') . '/cloudwords-form.js';

  return $form;
}

function cloudwords_settings_form_validate($form, &$form_state) {
  if ($form_state['values']['cloudwords_client_mode'] == 'stage') {
    if (!empty($form_state['values']['cloudwords_app_url']) || !empty($form_state['values']['cloudwords_api_url'])) {

      if ($form_state['values']['cloudwords_app_url'] && $form_state['values']['cloudwords_app_url']) {
        $url_app_preffix = parse_url($form_state['values']['cloudwords_app_url']);
        $url_api_preffix = parse_url($form_state['values']['cloudwords_api_url']);

        if (valid_url($form_state['values']['cloudwords_app_url'], $absolute = TRUE) === false || $url_app_preffix['scheme'] != 'https') {
          form_set_error('cloudwords_app_url', t('Application URL is not a valid one or is not starting with https'));
        }
        if (valid_url($form_state['values']['cloudwords_api_url'], $absolute = TRUE) === false || $url_api_preffix['scheme'] != 'https') {
          form_set_error('cloudwords_api_url', t('API URL is not a valid one or is not starting with https'));
        }
      }
    }
    else {
      form_set_error('cloudwords_api_url', t('Please, provide a valid API URL'));
      form_set_error('cloudwords_app_url', t('Please, provide a valid Application URL'));
    }
  }
}

